@@ -4,7 +4,7 @@ import tensorflow as tf
 from swissarmykit.lib.core import Singleton, Config
 from swissarmykit.lib.inspector import Inspector
 
-from mlk.mlk.lib.core import Config as mlkConfig
+from mlk.lib.core import Config as mlkConfig
 
 physical_devices = tf.config.list_physical_devices('GPU')
 if physical_devices:
