@@ -8,7 +8,7 @@ from pprint import pprint
 from datetime import datetime, timedelta
 from os.path import expanduser
 
-from mlk.mlk.checker.checkutils import CheckUtils
+from mlk.checker.checkutils import CheckUtils
 
 
 class Config():
